pub struct Simplex<const N: usize> {
pub neighbours: [usize; N],
pub vertices: [usize; N],
}Expand description
Euclidean (N-1)-simplex, built from N vertices.
The intended neighbours and vertices ordering is such that the vertex corresponding
to a neighbouring simplex is the vertex opposite the simplex. Additionally the overall
ordering is supposed to be consistent, such that the simplices are oriented.
Fields
neighbours: [usize; N]vertices: [usize; N]Implementations
Sourceimpl<const N: usize> Simplex<N>
Methods for working with Simplex<N> when neighbours are encoded by half-faces,
see Triangulation
impl<const N: usize> Simplex<N>
Methods for working with Simplex<N> when neighbours are encoded by half-faces,
see Triangulation
Sourcepub fn get_neighbour(&self, index: usize) -> usize
pub fn get_neighbour(&self, index: usize) -> usize
Returns the label of the neighbouring (N-1)-simplex on the index side.
Panic
This method will panic index >= N
Sourcepub fn get_neighbour_backindex(&self, index: usize) -> (usize, usize)
pub fn get_neighbour_backindex(&self, index: usize) -> (usize, usize)
Returns the label and backindex of neighbouring (N-1)-simplex on the index side.
Panic
This method will panic index >= N
Sourcepub fn get_neighbours(&self) -> [usize; N]
pub fn get_neighbours(&self) -> [usize; N]
Returns the neighbouring (N-1)-simplex labels of the Simplex
Sourcepub fn get_neighbours_backindices(&self) -> [(usize, usize); N]
pub fn get_neighbours_backindices(&self) -> [(usize, usize); N]
Returns the neighbouring (N-1)-simplex labels and back indices in tuple pairs